@@ -13,6 +13,9 @@ def convert_string(s):
     dt_object = parser.parse(s)
     return dt_object.timestamp()
 
+def convert_datetime(d):
+    return str(d.date())+'T00:00:00Z'
+
 
 def get_events_augmento(currency='bitcoin', startdate='2018-01-01T00:00:00Z', enddate='2019-10-01T00:00:00Z', source='twitter', precision='24H', local_root_directory=None):
     r = requests.request("GET", "http://api-dev.augmento.ai/v0.1/coins")
@@ -23,14 +26,8 @@ def get_events_augmento(currency='bitcoin', startdate='2018-01-01T00:00:00Z', en
     # print('Topics available\n', topics, '\n')
     topics = topics.values()
 
-    startdate_unix, enddate_unix = convert_string(startdate), convert_string(enddate)
+    startdate_unix, enddate_unix = startdate.timestamp(), enddate.timestamp()
     precision_dct = {'1H':3600, '24H':3600*24, 'hour': 3600, 'daily': 3600*24}
-    currency_dict = {'bitcoin':'BTC', 'ethereum':'ETH'}
-
-    start_date = datetime.datetime.fromtimestamp(startdate_unix).date()
-    end_date = datetime.datetime.fromtimestamp(enddate_unix).date()
-
-    pickle_saving_path = local_root_directory + source + '_' + currency_dict[currency] + '_' + str(start_date) + '_'+ str(end_date)+'_'+'augmento.pkl'
     runs, rest = divmod((enddate_unix-startdate_unix)/precision_dct[precision], 1000)
     rest = int(math.ceil(rest))
     url = "http://api-dev.augmento.ai/v0.1/events/aggregated"
@@ -40,9 +37,10 @@ def get_events_augmento(currency='bitcoin', startdate='2018-01-01T00:00:00Z', en
       "bin_size" : precision,
       "count_ptr" : 1000,
       "start_ptr" : 0,
-      "start_datetime": startdate,
-      "end_datetime" : enddate} # "start_datetime" : "2019-05-01T00:00:00Z",
+      "start_datetime": convert_datetime(startdate),
+      "end_datetime" : convert_datetime(enddate)} # "start_datetime" : "2019-05-01T00:00:00Z",
     output = pd.DataFrame()
+    print(params)
     if runs != 0:
         for run in range(int(runs)):
             r = requests.request("GET", url, params=params)
@@ -63,12 +61,12 @@ def get_events_augmento(currency='bitcoin', startdate='2018-01-01T00:00:00Z', en
     else:
         tmp = pd.DataFrame(r.json())
         tmp = pd.DataFrame(tmp['counts'].tolist(),index = tmp.datetime, columns = topics)
-        output = pd.concat([output, tmp])
-        output.to_pickle(pickle_saving_path)
+        output = pd.concat([output, tmp[1:]])
+    # output = output.drop_duplicates()
     return output
 
 
-def get_daily_data_augmento(currency='BTC', startdate='2018-01-01T00:00:00Z', enddate='2019-10-01T00:00:00Z', local_root_directory=None, target_present=False):
+def get_daily_data_augmento(currency='BTC', startdate=None, enddate=None, local_root_directory=None, target_present=False):
     currency_dict = {'BTC': 'bitcoin', 'ETH': 'ethereum'}
     frequence = 'daily'
 
@@ -101,14 +99,14 @@ def get_daily_data_augmento(currency='BTC', startdate='2018-01-01T00:00:00Z', en
     aggregated_df = aggregated_df.merge(reddit, left_index=True, right_index=True)
     aggregated_df = aggregated_df.merge(bitcointalk, left_index=True, right_index=True)
 
-    start_datetime = datetime.datetime.fromtimestamp(convert_string(startdate))
-    end_datetime = datetime.datetime.fromtimestamp(convert_string(enddate))
+    # start_datetime = datetime.datetime.fromtimestamp(convert_string(startdate))
+    # end_datetime = datetime.datetime.fromtimestamp(convert_string(enddate))
 
     if target_present:
         freqly_pkl_file_name_suffix = '_' + frequence + '_returns.pkl'
         refetch_all = True
-        starting_date = start_datetime
-        running_date = end_datetime
+        starting_date = startdate
+        running_date = enddate
         underlying_df = napoleon_connector.fetch_crypto_daily_data(ssj=currency, local_root_directory=local_root_directory,
                                                                daily_return_pkl_filename_suffix=freqly_pkl_file_name_suffix,
                                                                refetch_all=refetch_all,
@@ -118,14 +116,14 @@ def get_daily_data_augmento(currency='BTC', startdate='2018-01-01T00:00:00Z', en
         underlying_df = underlying_df.rename(columns={'volumefrom': 'volume'})
         aggregated_df = aggregated_df.merge(underlying_df, left_index=True, right_index=True)
 
-
-
-    pickle_saving_path = local_root_directory + frequence + '_' + 'all_sources' + '_' + currency + '_' + str(start_datetime.date()) + '_' + str(end_datetime.date()) + '_' + 'augmento.pkl'
+    dates_stub = startdate.strftime('%d_%b_%Y') + '_' + enddate.strftime('%d_%b_%Y')
+    augmento_suffix = '_augmento.pkl'
+    pickle_saving_path = local_root_directory + currency + '_' + frequence + '_' + dates_stub + augmento_suffix
     aggregated_df.to_pickle(pickle_saving_path)
     return aggregated_df
 
 
-def get_hourly_data_augmento(currency='BTC', startdate='2018-01-01T00:00:00Z', enddate='2019-10-01T00:00:00Z', local_root_directory=None, target_present=False):
+def get_hourly_data_augmento(currency='BTC', startdate=None, enddate=None, local_root_directory=None, target_present=False):
     currency_dict = {'BTC': 'bitcoin', 'ETH': 'ethereum'}
     frequence = 'hourly'
 
@@ -158,20 +156,21 @@ def get_hourly_data_augmento(currency='BTC', startdate='2018-01-01T00:00:00Z', e
     aggregated_df = aggregated_df.merge(reddit, left_index=True, right_index=True)
     aggregated_df = aggregated_df.merge(bitcointalk, left_index=True, right_index=True)
 
-    start_datetime = datetime.datetime.fromtimestamp(convert_string(startdate))
-    end_datetime = datetime.datetime.fromtimestamp(convert_string(enddate))
+    # start_datetime = datetime.datetime.fromtimestamp(convert_string(startdate))
+    # end_datetime = datetime.datetime.fromtimestamp(convert_string(enddate))
 
     if target_present:
         freqly_pkl_file_name_suffix = '_' + frequence + '_returns.pkl'
         refetch_all = True
-        starting_date = start_datetime
-        running_date = end_datetime
+        starting_date = startdate
+        running_date = enddate
         underlying_df = napoleon_connector.fetch_crypto_hourly_data(ssj = currency, local_root_directory=local_root_directory, hourly_return_pkl_filename_suffix = freqly_pkl_file_name_suffix, refetch_all = refetch_all,daily_crypto_starting_day=starting_date,daily_crypto_ending_day= running_date)
         underlying_df = underlying_df.drop(columns=['volumeto'])
         underlying_df = underlying_df.rename(columns={'volumefrom': 'volume'})
         aggregated_df = aggregated_df.merge(underlying_df, left_index=True, right_index=True)
 
-    pickle_saving_path = local_root_directory + frequence + '_' + 'all_sources' + '_' + currency + '_' + str(
-        start_datetime.date()) + '_' + str(end_datetime.date()) + '_' + 'augmento.pkl'
+    dates_stub = startdate.strftime('%d_%b_%Y') + '_' + enddate.strftime('%d_%b_%Y')
+    augmento_suffix = '_augmento.pkl'
+    pickle_saving_path = local_root_directory + currency + '_' + frequence + '_' + dates_stub + augmento_suffix
     aggregated_df.to_pickle(pickle_saving_path)
     return aggregated_df
\ No newline at end of file
