@@ -15,6 +15,7 @@ from napoleontoolbox.forecasting import lgbm_model_wrapper
 from napoleontoolbox.forecasting import arima_model_wrapper
 from napoleontoolbox.forecasting import sma_model_wrapper
 from napoleontoolbox.forecasting import simple_threshold_model_wrapper
+from napoleontoolbox.forecasting import simple_baseline
 
 from abc import ABC, abstractmethod
 
@@ -28,6 +29,8 @@ def instantiate_model(method = 'default',idios = {}):
         return sma_model_wrapper.SmaModel(**idios)
     if method == 'simple_threshold':
         return simple_threshold_model_wrapper.SimpleThresholdModel(**idios)
+    if method == 'simple_baseline':
+        return simple_baseline.BaselineModel(**idios)
 
 class AbstractForecasterWrapper(ABC):
     def __init__(self):
