@@ -1,7 +1,7 @@
 import numpy as np
 import pandas as pd
 
-def drop_most_correlated_features(X,threshold):
+def most_correlated_features(X,threshold):
     generic_features = ['close','high', 'low', 'open', 'volume']
     columns_to_compute = [col for col in X.columns if col not in generic_features]
     output_correlations = []
@@ -10,9 +10,9 @@ def drop_most_correlated_features(X,threshold):
             left_feature = columns_to_compute[i]
             right_feature=columns_to_compute[j]
             if left_feature != right_feature:
-                print(left_feature, right_feature)
-                print(X[left_feature].nunique())
-                print('done')
+                # print(left_feature, right_feature)
+                # print(X[left_feature].nunique())
+                # print('done')
                 correlation_matrix = np.corrcoef(X[left_feature],X[right_feature])
                 output_correlations.append(
                     {
@@ -25,5 +25,13 @@ def drop_most_correlated_features(X,threshold):
     output_correlations_df = pd.DataFrame(output_correlations)
     output_correlations_df['abs_correlation'] = abs(output_correlations_df['correlation'] )
     output_correlations_df = output_correlations_df.sort_values(by='abs_correlation', ascending=False)
-    X=X.drop(output_correlations_df.loc[output_correlations_df['abs_correlation'] > threshold]['daily_feature_2'].unique(),axis=1)
-    return X
+    columns_to_drop = output_correlations_df.loc[output_correlations_df['abs_correlation'] > threshold]['daily_feature_2'].unique()
+    return columns_to_drop
+
+
+def get_binarization_threshold(X):
+        return X.mean().to_dict()
+
+def binarize_features(X,features_threshold):
+    X[list(features_threshold.keys())] = (X[features_threshold.keys()] >= list(features_threshold.values())).astype(int)
+    return X
\ No newline at end of file
