@@ -23,6 +23,10 @@ import numpy as np
 
 from dateutil import parser
 
+def rescalize(y, range1, range2):
+    delta1 = range1[1] - range1[0]
+    delta2 = range2[1] - range2[0]
+    return (delta2 * (y - range1[0]) / delta1) + range2[0]
 
 class AbstractRunner(ABC):
     def __init__(self, starting_date = None, running_date = None, drop_token=None, dropbox_backup = True, underlying=None, frequence = None, target='target', local_root_directory='../data/', user = 'napoleon', number_per_year=252, augmento_suffix = '_augmento.pkl'):
@@ -52,7 +56,9 @@ class AbstractRunner(ABC):
 
 class  Augmento_ForecasterRunner(AbstractRunner):
     def runTrial(self, saver, seed, n, s, s_eval, calibration_step, signal_type, idios_string):
-        continuous_saving_key, two_states_saving_key, two_states_saving_key_lo, three_states_saving_key, three_states_saving_key_lo , idios= saver.create_saving_key(seed, n, s, s_eval, calibration_step, signal_type, idios_string)
+        continuous_saving_key, continuous_saving_key_scale_one, continuous_saving_key_scale_two, two_states_saving_key, two_states_saving_key_lo, three_states_saving_key, three_states_saving_key_lo, idios = saver.create_saving_key(
+            seed, n, s, s_eval, calibration_step, signal_type, idios_string)
+
         check_run_existence, table_number = saver.checkRunExistence(continuous_saving_key)
         exhaustive_check_run_existence, exhaustive_table_number = saver.exhaustiveCheckRunExistence(continuous_saving_key)
         assert check_run_existence == exhaustive_check_run_existence
@@ -87,8 +93,9 @@ class  Augmento_ForecasterRunner(AbstractRunner):
         features_colmuns = [col for col in timeseries_df.columns if col not in generic_columns]
 
         timeseries_df['close_return']= timeseries_df['close'].pct_change()
-
-
+        timeseries_df['shifted_close_return']= timeseries_df['close'].pct_change().shift(-1)
+        timeseries_df=timeseries_df.iloc[:-1]
+        y_true = timeseries_df['close_return']
         X, y = timeseries_df.loc[:, features_colmuns], timeseries_df[self.target]
         print('predictors shape')
         print(X.shape)
@@ -111,6 +118,12 @@ class  Augmento_ForecasterRunner(AbstractRunner):
             method = chosen_method,
             display = True)
 
+        forecasted_series = forecasted_series.shift(1)
+        discrete_two_states_forecasting_series = discrete_two_states_forecasting_series.shift(1)
+        discrete_two_states_forecasting_series_lo = discrete_two_states_forecasting_series_lo.shift(1)
+        discrete_three_states_forecasting_series = discrete_three_states_forecasting_series.shift(1)
+        discrete_three_states_forecasting_series_lo = discrete_three_states_forecasting_series_lo.shift(1)
+
         print('mixing backtest done')
         features_importances = features_importances.sum(axis = 0)
         print('features importance')
@@ -142,22 +155,76 @@ class  Augmento_ForecasterRunner(AbstractRunner):
         transaction_cost = True
         if self.frequence=='minutely':
             transaction_cost = False
+            # saving the continuous signal
+        print('max prediction signal')
+        print(max(forecasted_series))
+        print('min prediction signal')
+        print(min(forecasted_series))
+        scale_one = 2.
+        forecasted_series_scale_one = rescalize(forecasted_series, [min(forecasted_series), max(forecasted_series)],
+                                                [-scale_one, scale_one])
+        scale_two = 1.
+        forecasted_series_scale_two = rescalize(forecasted_series, [min(forecasted_series), max(forecasted_series)],
+                                                [-scale_two, scale_two])
+        scale_three = 0.5
+        forecasted_series_scale_three = rescalize(forecasted_series, [min(forecasted_series), max(forecasted_series)],
+                                                  [-scale_three, scale_three])
 
-        #saving the continuous signal
-        perf_df = signal_utility.reconstitute_prediction_perf(y_pred=forecasted_series, y_true = y, transaction_cost=transaction_cost, print_turnover=False)
-        sharpe_strat = metrics.sharpe(perf_df['perf_return'].dropna(), period= self.number_per_year, from_ret=True)
-        sharpe_under = metrics.sharpe(perf_df['close_return'].dropna(), period= self.number_per_year, from_ret=True)
+        forecasted_series_scale_one = np.clip(forecasted_series_scale_one, a_min=-1., a_max=1.)
+        forecasted_series_scale_two = np.clip(forecasted_series_scale_two, a_min=-1., a_max=1.)
+        forecasted_series_scale_three = np.clip(forecasted_series_scale_three, a_min=-1., a_max=1.)
+
+        print('scale one max prediction signal')
+        print(max(forecasted_series_scale_one))
+        print('scale one min prediction signal')
+        print(min(forecasted_series_scale_one))
+
+        print('scale two max prediction signal')
+        print(max(forecasted_series_scale_two))
+        print('scale two min prediction signal')
+        print(min(forecasted_series_scale_two))
+
+        print('scale three max prediction signal')
+        print(max(forecasted_series_scale_three))
+        print('scale three min prediction signal')
+        print(min(forecasted_series_scale_three))
+
+        perf_df = signal_utility.reconstitute_prediction_perf(y_pred=forecasted_series_scale_one, y_true=y_true,
+                                                              transaction_cost=transaction_cost, print_turnover=False)
+        sharpe_strat = metrics.sharpe(perf_df['perf_return'].dropna(), period=self.number_per_year, from_ret=True)
+        sharpe_under = metrics.sharpe(perf_df['close_return'].dropna(), period=self.number_per_year, from_ret=True)
         print('underlying sharpe')
         print(sharpe_under)
         print('strat sharpe')
         print(sharpe_strat)
         saver.saveAll(continuous_saving_key, perf_df)
 
+        perf_df = signal_utility.reconstitute_prediction_perf(y_pred=forecasted_series_scale_two, y_true=y_true,
+                                                              transaction_cost=transaction_cost, print_turnover=False)
+        sharpe_strat = metrics.sharpe(perf_df['perf_return'].dropna(), period=self.number_per_year, from_ret=True)
+        sharpe_under = metrics.sharpe(perf_df['close_return'].dropna(), period=self.number_per_year, from_ret=True)
+        print('underlying sharpe')
+        print(sharpe_under)
+        print('strat sharpe')
+        print(sharpe_strat)
+        saver.saveAll(continuous_saving_key_scale_one, perf_df)
 
-        #saving the 2 states signal
-        perf_df = signal_utility.reconstitute_prediction_perf(y_pred= discrete_two_states_forecasting_series , y_true = y, transaction_cost=transaction_cost, print_turnover=False)
-        sharpe_strat = metrics.sharpe(perf_df['perf_return'].dropna(), period= self.number_per_year, from_ret=True)
-        sharpe_under = metrics.sharpe(perf_df['close_return'].dropna(), period= self.number_per_year, from_ret=True)
+        perf_df = signal_utility.reconstitute_prediction_perf(y_pred=forecasted_series_scale_three, y_true=y_true,
+                                                              transaction_cost=transaction_cost, print_turnover=False)
+        sharpe_strat = metrics.sharpe(perf_df['perf_return'].dropna(), period=self.number_per_year, from_ret=True)
+        sharpe_under = metrics.sharpe(perf_df['close_return'].dropna(), period=self.number_per_year, from_ret=True)
+        print('underlying sharpe')
+        print(sharpe_under)
+        print('strat sharpe')
+        print(sharpe_strat)
+        saver.saveAll(continuous_saving_key_scale_two, perf_df)
+
+        # saving the 2 states signal
+        perf_df = signal_utility.reconstitute_prediction_perf(y_pred=discrete_two_states_forecasting_series,
+                                                              y_true=y_true, transaction_cost=transaction_cost,
+                                                              print_turnover=False)
+        sharpe_strat = metrics.sharpe(perf_df['perf_return'].dropna(), period=self.number_per_year, from_ret=True)
+        sharpe_under = metrics.sharpe(perf_df['close_return'].dropna(), period=self.number_per_year, from_ret=True)
         print('underlying sharpe')
         print(sharpe_under)
         print('strat sharpe')
@@ -165,7 +232,8 @@ class  Augmento_ForecasterRunner(AbstractRunner):
         saver.saveAll(two_states_saving_key, perf_df)
 
         # saving the 2 states signal long only
-        perf_df = signal_utility.reconstitute_prediction_perf(y_pred=discrete_two_states_forecasting_series_lo, y_true=y,
+        perf_df = signal_utility.reconstitute_prediction_perf(y_pred=discrete_two_states_forecasting_series_lo,
+                                                              y_true=y_true,
                                                               transaction_cost=transaction_cost, print_turnover=False)
         sharpe_strat = metrics.sharpe(perf_df['perf_return'].dropna(), period=self.number_per_year, from_ret=True)
         sharpe_under = metrics.sharpe(perf_df['close_return'].dropna(), period=self.number_per_year, from_ret=True)
@@ -175,11 +243,12 @@ class  Augmento_ForecasterRunner(AbstractRunner):
         print(sharpe_strat)
         saver.saveAll(two_states_saving_key_lo, perf_df)
 
-
-        #saving the 3 states signal
-        perf_df = signal_utility.reconstitute_prediction_perf(y_pred=discrete_three_states_forecasting_series, y_true = y, transaction_cost=transaction_cost, print_turnover=False)
-        sharpe_strat = metrics.sharpe(perf_df['perf_return'].dropna(), period= self.number_per_year, from_ret=True)
-        sharpe_under = metrics.sharpe(perf_df['close_return'].dropna(), period= self.number_per_year, from_ret=True)
+        # saving the 3 states signal
+        perf_df = signal_utility.reconstitute_prediction_perf(y_pred=discrete_three_states_forecasting_series,
+                                                              y_true=y_true, transaction_cost=transaction_cost,
+                                                              print_turnover=False)
+        sharpe_strat = metrics.sharpe(perf_df['perf_return'].dropna(), period=self.number_per_year, from_ret=True)
+        sharpe_under = metrics.sharpe(perf_df['close_return'].dropna(), period=self.number_per_year, from_ret=True)
         print('underlying sharpe')
         print(sharpe_under)
         print('strat sharpe')
@@ -187,7 +256,8 @@ class  Augmento_ForecasterRunner(AbstractRunner):
         saver.saveAll(three_states_saving_key, perf_df)
 
         # saving the 3 states signal long only
-        perf_df = signal_utility.reconstitute_prediction_perf(y_pred=discrete_three_states_forecasting_series_lo, y_true=y,
+        perf_df = signal_utility.reconstitute_prediction_perf(y_pred=discrete_three_states_forecasting_series_lo,
+                                                              y_true=y_true,
                                                               transaction_cost=transaction_cost, print_turnover=False)
         sharpe_strat = metrics.sharpe(perf_df['perf_return'].dropna(), period=self.number_per_year, from_ret=True)
         sharpe_under = metrics.sharpe(perf_df['close_return'].dropna(), period=self.number_per_year, from_ret=True)
