@@ -4,6 +4,7 @@
 from abc import ABC, abstractmethod
 
 import pandas as pd
+import numpy as np
 
 from napoleontoolbox.file_saver import dropbox_file_saver
 from napoleontoolbox.signal import signal_generator
@@ -15,11 +16,33 @@ import json
 
 from pathlib import Path
 
+def daily_bc_apply_standard_mean_two_states_discretization(signals_df=None, s=21):
+    day_signal_columns = [me_sig for me_sig in signals_df.columns if 'signal' in me_sig ]
+    signals_np = signals_df[day_signal_columns].values  # [:, len(self.generic_columns):]
+    full_y_true = signals_df['close'].pct_change().fillna(0.)
+    y_pred_discretized = np.zeros(full_y_true.shape)
+    for row_index in range(s, signals_np.shape[0]):
+        starting_train = row_index - s
+        stopping_train = row_index
+        prediction = row_index
+        rolling_np = signals_np[starting_train:stopping_train, :]
+        y_train_true = full_y_true[starting_train:stopping_train]
+        y_train_pred = np.mean(rolling_np, axis=1)
+        splitting_quantile_threshold, splitting_threshold, sharpe_strat, sharpe_under = signal_utility.find_best_two_states_discretization(
+            y_train_pred, y_train_true)
+        y_next_pred = np.nanmean(signals_np[row_index, :])
+        y_next_pred_discrete = signal_utility.apply_discretization_two_states(y_next_pred, splitting_threshold)
+        y_pred_discretized[prediction] = y_next_pred_discrete
+    return y_pred_discretized
+
 class AbstractRunner(ABC):
-    def __init__(self, starting_date = None, running_date = None, drop_token=None, dropbox_backup = True, underlying = None, frequence='daily', selected_algo='',algo='' ,freqly_return_pkl_filename_suffix='freqly_candels.pkl',aggregated_pkl_file_suffix='freqly_to_mix.pkl', aggregated_pkl_mapping_file_suffix = 'freqly_to_mix_mapping.pkl', list_pkl_file_suffix = 'my_list.pkl', local_root_directory='../data/', user = 'napoleon', add_turn_over = False, skipping_size=200, recompute_all = True, db_path_suffix=None):
+    def __init__(self, calibration_starting_date = None,  calibration_running_date = None, starting_date = None,  running_date = None,  drop_token=None, dropbox_backup = True, underlying = None, frequence='daily', selected_algo='',algo='' ,freqly_return_pkl_filename_suffix='freqly_candels.pkl',aggregated_pkl_file_suffix='freqly_to_mix.pkl', aggregated_pkl_mapping_file_suffix = 'freqly_to_mix_mapping.pkl', list_pkl_file_suffix = 'my_list.pkl', local_root_directory='../data/', user = 'napoleon', add_turn_over = False, skipping_size=200, recompute_all = True, db_path_suffix=None, daily_ia_lookback_window=21):
         super().__init__()
         self.starting_date = starting_date
         self.running_date = running_date
+        self.calibration_starting_date = calibration_starting_date
+        self.calibration_running_date = calibration_running_date
+
         self.freqly_return_pkl_filename_suffix=freqly_return_pkl_filename_suffix
         self.aggregated_pkl_file_suffix=aggregated_pkl_file_suffix
         self.aggregated_pkl_mapping_file_suffix=aggregated_pkl_mapping_file_suffix
@@ -29,7 +52,7 @@ class AbstractRunner(ABC):
         self.algo=algo
         self.selected_algo=selected_algo
 
-        self.dates_stub = self.starting_date.strftime('%d_%b_%Y') + '_' + self.running_date.strftime('%d_%b_%Y')
+        self.dates_stub = self.calibration_starting_date.strftime('%d_%b_%Y') + '_' + self.calibration_running_date.strftime('%d_%b_%Y')
         self.list_pkl_file_name = self.dates_stub +'_' +self.underlying + '_' + self.frequence + '_' + self.selected_algo + self.list_pkl_file_suffix
         self.aggregated_pkl_file_name = self.dates_stub +'_' + self.underlying + '_' + self.frequence + '_' + self.selected_algo + self.aggregated_pkl_file_suffix
         self.aggregated_pkl_mapping_file_name = self.dates_stub +'_'+ self.underlying + '_' + self.frequence + '_' + self.selected_algo + self.aggregated_pkl_mapping_file_suffix
@@ -67,7 +90,9 @@ class AbstractRunner(ABC):
                                                                  local_root_directory=local_root_directory, user=user,
                                                                  db_path_name=self.db_path_name)
         self.precomputed_results_df, self.precomputed_signals_df = saver.analyzeAllRunResults()
+        self.daily_ia_lookback_window = daily_ia_lookback_window
         print('done')
+
     @abstractmethod
     def runTrial(self,saver):
         pass
@@ -145,6 +170,9 @@ class AggregatingSignalRunner(AbstractRunner):
             else:
                 cumulated_signals = freqly_df[['close', 'signal']].copy()
                 cumulated_signals = cumulated_signals.rename(columns={'signal': me_signal})
+
+
+            print('diiscretizing the signal ')
             return cumulated_signals
         except Exception as e:
             print('cannot compute ', me_signal)
@@ -171,8 +199,6 @@ class AggregatingSignalRunner(AbstractRunner):
             print(min(freqly_df.index))
             close_df = freqly_df.copy()
 
-
-
             ## idiosyncratic run itself
             run_json_string = signal_utility.recover_to_sql_column_format(me_signal)
             params = json.loads(run_json_string)
@@ -242,13 +268,14 @@ class AggregatingSignalRunner(AbstractRunner):
             counter = counter + 1
 
 
-        print('saving to '+self.aggregated_pkl_file_name)
-        cumulated_signals.to_pickle(self.local_root_directory+self.aggregated_pkl_file_name)
-        print('saving to '+self.aggregated_pkl_mapping_file_name)
-        pd.DataFrame(mapping_dictionary).to_pickle(self.local_root_directory + self.aggregated_pkl_mapping_file_name)
+        self.saving_cumulated_signals(cumulated_signals,mapping_dictionary)
 
 
     def saving_cumulated_signals(self, cumulated_signals_df, mapping_dictionary):
+        print('discretizing the cumulated signals using ia')
+        discrete_daily_signals = daily_bc_apply_standard_mean_two_states_discretization(signals_df=cumulated_signals_df, s=self.daily_ia_lookback_window)
+        cumulated_signals_df['trend']=discrete_daily_signals
+        print(f'discretization done {len(discrete_daily_signals)}')
         print('saving to ' + self.aggregated_pkl_file_name)
         cumulated_signals_df.to_pickle(self.local_root_directory + self.aggregated_pkl_file_name)
         print('saving to '+self.aggregated_pkl_mapping_file_name)
@@ -260,6 +287,3 @@ class AggregatingSignalRunner(AbstractRunner):
 
 
 
-
-
-
