@@ -365,6 +365,10 @@ def compute_signals_weights_perf(data = None, optimal_weights = None, starting_d
 
 def recompute_perf_returns(signals_df, close_df, transac_cost=True, print_turnover = False):
     results_df = pd.concat([signals_df, close_df], axis=1).reindex(signals_df.index)
+    if 'close_return' not in results_df.columns:
+        results_df['close_return'] = results_df['shifted_close_return'].shift(1)
+        results_df = results_df.iloc[1:]
+
     signals_returns_df = None
     for sig in results_df.columns:
         if 'signal' in sig:
@@ -422,6 +426,13 @@ def apply_discretization_two_states_lo(y_pred, splitting_threshold):
     y_pred_discrete = np.zeros(y_pred.shape)
     if np.isnan(splitting_threshold) :
         splitting_threshold = 0.5
+
+    if np.isscalar(y_pred):
+        if y_pred > splitting_threshold:
+            return 1.
+        else:
+            return 0.
+
     y_pred_discrete[y_pred > splitting_threshold] = 1.
     y_pred_discrete[y_pred < splitting_threshold] = 0.
     return y_pred_discrete
@@ -454,6 +465,7 @@ def apply_discretization_three_states(y_pred, upper_threshold, lower_threshold):
 
 
 def discretize_three_states(y_pred, upper_quantile_threshold=0.8, lower_quantile_threshold = 0.2):
+
     y_pred_discrete = np.zeros(y_pred.shape)
 
     lower_threshold = np.nan
@@ -470,17 +482,36 @@ def discretize_three_states(y_pred, upper_quantile_threshold=0.8, lower_quantile
         print(e)
         print("the quantile could not get computed")
 
+
     if np.isnan(upper_threshold):
         upper_threshold = 0.8
     if np.isnan(lower_threshold):
         lower_threshold = 0.2
 
+    if np.isscalar(y_pred):
+        if y_pred > upper_threshold:
+            return 1.
+        elif y_pred < lower_threshold:
+            return -1.
+        else:
+            return 0.
+
+
     y_pred_discrete[y_pred > upper_threshold] = 1.
     y_pred_discrete[y_pred < lower_threshold] = -1.
     return y_pred_discrete
 
 
 def apply_discretization_three_states_lo(y_pred, upper_threshold, lower_threshold):
+    if np.isscalar(y_pred):
+        if y_pred > upper_threshold:
+            return 1.
+        elif y_pred < lower_threshold:
+            return 0.
+        else:
+            return 0.5
+
+
     y_pred_discrete = np.ones(y_pred.shape)/2
 
     if np.isnan(upper_threshold):
@@ -520,9 +551,18 @@ def discretize_three_states_lo(y_pred, upper_quantile_threshold=0.8, lower_quant
     return y_pred_discrete
 
 def apply_discretization_two_states(y_pred, splitting_threshold):
+
+
     y_pred_discrete = np.zeros(y_pred.shape)
     if np.isnan(splitting_threshold) :
         splitting_threshold = 0.5
+
+    if np.isscalar(y_pred):
+        if y_pred > splitting_threshold:
+            return 1.
+        else:
+            return -1.
+
     y_pred_discrete[y_pred > splitting_threshold] = 1.
     y_pred_discrete[y_pred < splitting_threshold] = -1.
     return y_pred_discrete
